App

Struct App 

pub struct App<COMP: Component> { /* private fields */ }
An application instance.

Implementations

Source

impl<COMP> App<COMP>
where COMP: Component + Renderable<COMP>,

pub fn new() -> Self

Creates a new App with a component in a context.

pub fn mount_to_body(self) -> Scope<COMP>

Alias to mount("body", ...).

pub fn mount_to_selector(self, selector: &str) -> Scope<COMP>

Alias to mount() that allows using a selector

pub fn mount_with_props( self, element: Element, props: COMP::Properties, ) -> Scope<COMP>

Alias to mount() that allows passing in initial props

pub fn mount( self, element: Element, props: Option<COMP::Properties>, ) -> Scope<COMP>

The main entrypoint of a yew program. It works similar as program function in Elm. You should provide an initial model, update function which will update the state of the model and a view function which will render the model to a virtual DOM tree.